summaryrefslogtreecommitdiff
path: root/xmake/modules/private
diff options
context:
space:
mode:
authorruki <[email protected]>2022-04-13 23:06:03 +0800
committerruki <[email protected]>2022-04-13 23:06:03 +0800
commitc6c62b573fb79dbf89733591f46ce92e10ee6fab (patch)
tree2dca011079f154c5fd9b6a24853ceda61d5194c5 /xmake/modules/private
parent9e4be5c8d422a2f089e15679865b217d0958b98c (diff)
add git.push
Diffstat (limited to 'xmake/modules/private')
-rw-r--r--xmake/modules/private/service/remote_build/client.lua8
1 files changed, 3 insertions, 5 deletions
diff --git a/xmake/modules/private/service/remote_build/client.lua b/xmake/modules/private/service/remote_build/client.lua
index 1031aec60..19e739409 100644
--- a/xmake/modules/private/service/remote_build/client.lua
+++ b/xmake/modules/private/service/remote_build/client.lua
@@ -269,14 +269,12 @@ function remote_build_client:_do_syncfiles(remote_path, remote_branch)
local user = assert(config.get("remote_build.client.user"), "config(remote_build.client.user): not found!")
local pass = config.get("remote_build.client.pass")
local addr = self:addr()
- local branch = git.branch({repodir = os.curdir()})
- assert(branch, "git branch not found!")
assert(remote_path, "git remote path not found!")
assert(remote_branch, "git remote branch not found!")
- -- get remote url
- local remote_url = string.format("%s@%s:%s %s:%s", user, addr, remote_path, branch, remote_branch)
- print(remote_url)
+ -- push to remote
+ local remote_url = string.format("%s@%s:%s", user, addr, remote_path)
+ git.push(remote_url, {remote_branch = remote_branch, password = pass})
end
function remote_build_client:__tostring()